
package Google::Ads::AdWords::v201309::TypeMaps::AdGroupAdService;
use strict;
use warnings;

our $typemap_1 = {
               'queryResponse/rval/entries/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'mutateResponse/rval/value/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors' => 'Google::Ads::AdWords::v201309::ApiError',
               'getResponse/rval/entries/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/partialFailureErrors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'mutateResponse/rval/value/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201309::Predicate',
               'queryResponse/rval/entries/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'getResponse/rval/entries/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutateResponse/rval/value/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations/operand/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'mutateResponse/rval/value/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/value/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations/operand/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/exemptionRequests' => 'Google::Ads::AdWords::v201309::ExemptionRequest',
               'queryResponse/rval/entries/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::AdGroupAdCountLimitExceeded',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201309::Predicate::Operator',
               'mutateResponse/rval/partialFailureErrors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'mutateResponse/rval/value/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/partialFailureErrors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'getResponse/rval/entries/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutateResponse/rval/partialFailureErrors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'mutate/operations/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutate/operations/operand/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'getResponse/rval/entries/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'getResponse/rval/entries/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'queryResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'mutate/operations/operand/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval/entries/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval/entries/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'mutate/operations/operand/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/value/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'mutateResponse/rval/value/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'mutate/operations/operand/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval' => 'Google::Ads::AdWords::v201309::AdGroupAdPage',
               'getResponse/rval/entries/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201309::ClientTermsError',
               'mutateResponse/rval/value/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations/operand/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations/operand/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'Fault/detail/ApiExceptionFault/errors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'mutate/operations/operand/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/value/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/value/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'mutate/operations/operand/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval/entries/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'mutateResponse/rval/partialFailureErrors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/reason' => 'Google::Ads::AdWords::v201309::DateError::Reason',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutate/operations/operand/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'mutateResponse/rval/partialFailureErrors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201309::Operator',
               'mutate/operations/operand/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'mutateResponse/rval/partialFailureErrors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'query' => 'Google::Ads::AdWords::v201309::AdGroupAdService::query',
               'mutateResponse/rval/value/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'mutateResponse/rval/value/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResponse/rval/entries/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'queryResponse/rval/entries/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'mutate/operations/operand/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'mutateResponse/rval/value/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'queryResponse/rval/entries/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/entries/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'mutateResponse/rval/partialFailureErrors[BetaError]' => 'Google::Ads::AdWords::v201309::BetaError',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'mutate/operations/operand/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations/operand/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'getResponse/rval/entries/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'queryResponse/rval/entries/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]' => 'Google::Ads::AdWords::v201309::StatsQueryError',
               'mutateResponse/rval/value/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201309::NotEmptyError',
               'mutate/operations/operand/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations/operand/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'mutate/operations/operand/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'getResponse/rval/entries/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'getResponse/rval/entries/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'mutateResponse/rval/partialFailureErrors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations/operand/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'queryResponse/rval/entries/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'mutate/operations/operand/ad[MobileImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'queryResponse/rval/entries/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201309::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201309::SortOrder',
               'mutateResponse/rval/value/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get' => 'Google::Ads::AdWords::v201309::AdGroupAdService::get',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[MediaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'getResponse/rval/entries/ad[DynamicSearchAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'mutate/operations/operand/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'queryResponse/rval/entries/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'mutateResponse/rval/partialFailureErrors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/exemptionRequests/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'getResponse/rval/entries/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'getResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201309::AuthenticationError::Reason',
               'queryResponse/rval/entries/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/partialFailureErrors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201309::QueryError::Reason',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'queryResponse/rval/entries/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201309::DistinctError::Reason',
               'mutateResponse/rval/partialFailureErrors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval/entries/ad[TextAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201309::NullError',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201309::AdGroupAdPage',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/entries/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'mutate/operations/operand/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'mutateResponse/rval/partialFailureErrors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PagingError]' => 'Google::Ads::AdWords::v201309::PagingError',
               'mutateResponse/rval/partialFailureErrors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/value/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201309::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'queryResponse/rval/entries/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[ImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations/operand/ad[ImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[MediaError]' => 'Google::Ads::AdWords::v201309::MediaError',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'mutate/operations/operand/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'mutate' => 'Google::Ads::AdWords::v201309::AdGroupAdService::mutate',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[DynamicSearchAd]' => 'Google::Ads::AdWords::v201309::DynamicSearchAd',
               'getResponse/rval/entries/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'Fault/detail/ApiExceptionFault/errors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'queryResponse/rval/entries/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201309::SizeLimitError::Reason',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/entries/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'mutateResponse/rval/partialFailureErrors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TextAd]' => 'Google::Ads::AdWords::v201309::TextAd',
               'getResponse/rval/entries/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/exemptionRequests/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded',
               'getResponse/rval/entries/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'mutateResponse/rval/partialFailureErrors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutateResponse/rval/value/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'queryResponse/rval/entries/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'getResponse/rval/entries/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201309::IdError',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201309::AdGroupAdReturnValue',
               'queryResponse/rval/entries/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[RichMediaAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201309::OperationAccessDenied::Reason',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]' => 'Google::Ads::AdWords::v201309::DatabaseError',
               'mutateResponse/rval/value/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'mutate/operations/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201309::ExperimentDeltaStatus',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/entries/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutateResponse/rval/value/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'mutateResponse/rval/value/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201309::Selector',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutateResponse/rval/partialFailureErrors[DistinctError]' => 'Google::Ads::AdWords::v201309::DistinctError',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201309::SelectorError',
               'mutateResponse/rval/value/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201309::EntityNotFound::Reason',
               'getResponse/rval/entries/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]' => 'Google::Ads::AdWords::v201309::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'mutate/operations/operand/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'mutate/operations/operand/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdxError]' => 'Google::Ads::AdWords::v201309::AdxError',
               'queryResponse/rval/entries/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdError]/reason' => 'Google::Ads::AdWords::v201309::AdError::Reason',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[ImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations/operand/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201309::NotEmptyError::Reason',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/partialFailureErrors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[RichMediaAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/certifiedVendorFormatId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201309::Paging',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201309::NewEntityCreationError',
               'queryResponse/rval/entries/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'mutateResponse/rval/value/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval/entries/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]' => 'Google::Ads::AdWords::v201309::PolicyViolationError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'mutate/operations/operand/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/isUserInterestTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'mutateResponse/rval/partialFailureErrors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'mutateResponse/rval/partialFailureErrors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'queryResponse/rval/entries/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ImageError]' => 'Google::Ads::AdWords::v201309::ImageError',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[ImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'queryResponse/rval/entries/ad[TextAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'mutateResponse/rval/partialFailureErrors[ImageError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/value/ad[RichMediaAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval/entries/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/partialFailureErrors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201309::DateError',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'mutateResponse/rval/partialFailureErrors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdError]/reason' => 'Google::Ads::AdWords::v201309::AdGroupAdError::Reason',
               'mutateResponse/rval/partialFailureErrors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'Fault/detail/ApiExceptionFault/errors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ProductAd]/promotionLine' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[DeprecatedAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ProductAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse' => 'Google::Ads::AdWords::v201309::AdGroupAdService::getResponse',
               'mutate/operations/operand/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutateResponse/rval/value/ad[TextAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201309::StatsQueryError::Reason',
               'mutate/operations/operand/experimentData' => 'Google::Ads::AdWords::v201309::AdGroupAdExperimentData',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]' => 'Google::Ads::AdWords::v201309::AdGroupAdError',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/violatingParts' => 'Google::Ads::AdWords::v201309::PolicyViolationError::Part',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts/length' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201309::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]' => 'Google::Ads::AdWords::v201309::RateExceededError',
               'mutateResponse/rval/value/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201309::InternalApiError::Reason',
               'getResponse/rval/entries/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileAd]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[DeprecatedAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[DynamicSearchAd]/description1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201309::SelectorError::Reason',
               'mutateResponse/rval/value/trademarkDisapproved' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[MobileImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/ad[TemplateAd]' => 'Google::Ads::AdWords::v201309::TemplateAd',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201309::AuthorizationError',
               'mutateResponse/rval/partialFailureErrors[PagingError]/reason' => 'Google::Ads::AdWords::v201309::PagingError::Reason',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'mutate/operations/operand/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ImageError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'queryResponse/rval/entries/ad[MobileAd]' => 'Google::Ads::AdWords::v201309::MobileAd',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval/entries/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'queryResponse/rval/entries/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutate/operations/operand/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'queryResponse/rval/entries/ad[MobileImageAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201309::SizeLimitError',
               'mutateResponse/rval/value/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'queryResponse/rval/entries/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/partialFailureErrors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/advertisingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse' => 'Google::Ads::AdWords::v201309::AdGroupAdService::queryResponse',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/industryStandardCommercialIdentifier' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ProductAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201309::AdGroupAd::Status',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201309::NewEntityCreationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RangeError]/reason' => 'Google::Ads::AdWords::v201309::RangeError::Reason',
               'mutate/operations/operand/ad[MobileImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'mutateResponse/rval/partialFailureErrors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'queryResponse/rval/entries/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/reason' => 'Google::Ads::AdWords::v201309::ForwardCompatibilityError::Reason',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutateResponse/rval/value/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/originAdId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]' => 'Google::Ads::AdWords::v201309::StringLengthError',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'queryResponse/rval/entries/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201309::RequestError',
               'getResponse/rval/entries/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201309::ExperimentDataStatus',
               'queryResponse/rval/entries/ad[ImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201309::RequiredError',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/adToCopyImageFrom' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[MobileImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201309::AuthenticationError',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/richMediaAdType' => 'Google::Ads::AdWords::v201309::RichMediaAd::RichMediaAdType',
               'mutateResponse/rval/value/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/violatingParts/index' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/disapprovalReasons' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileAd]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]' => 'Google::Ads::AdWords::v201309::QueryError',
               'getResponse/rval/entries/ad[TextAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[ImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201309::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AdError]' => 'Google::Ads::AdWords::v201309::AdError',
               'mutate/operations/operand/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse' => 'Google::Ads::AdWords::v201309::AdGroupAdService::mutateResponse',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields' => 'Google::Ads::AdWords::v201309::TemplateElementField',
               'mutate/operations/operand/ad[MobileImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201309::DatabaseError::Reason',
               'mutateResponse/rval/value/ad[TextAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad[MobileImageAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201309::OperationAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/key/policyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/videoTypes' => 'Google::Ads::AdWords::v201309::VideoType',
               'getResponse/rval/entries/ad[RichMediaAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'getResponse/rval/entries/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'queryResponse/rval/entries/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[BetaError]/reason' => 'Google::Ads::AdWords::v201309::BetaError::Reason',
               'mutateResponse/rval/value/ad[ProductAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/value/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/expandingDirections' => 'Google::Ads::AdWords::v201309::ThirdPartyRedirectAd::ExpandingDirection',
               'getResponse/rval/entries/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/adUnionId[TempAdUnionId]' => 'Google::Ads::AdWords::v201309::TempAdUnionId',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements' => 'Google::Ads::AdWords::v201309::TemplateElement',
               'mutate/operations/operand/ad[RichMediaAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/uniqueName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]' => 'Google::Ads::AdWords::v201309::ImageAd',
               'mutate/operations/operand/ad[ProductAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TextAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/adUnionId/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/exemptionRequests/key' => 'Google::Ads::AdWords::v201309::PolicyViolationKey',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/isTagged' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[MobileImageAd]/image/data' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[TemplateAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[MobileImageAd]/image/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201309::EntityNotFound',
               'getResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'getResponse/rval/entries/ad[MobileImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/reason' => 'Google::Ads::AdWords::v201309::ImageError::Reason',
               'mutate/operations/operand/ad[MobileAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[DeprecatedAd]/type' => 'Google::Ads::AdWords::v201309::DeprecatedAd::Type',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]' => 'Google::Ads::AdWords::v201309::Video',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/key/violatingText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]' => 'Google::Ads::AdWords::v201309::QuotaCheckError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/readyToPlayOnTheWeb' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[ImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201309::NotWhitelistedError::Reason',
               'mutateResponse/rval/partialFailureErrors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'mutateResponse/rval/value/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ProductAd]' => 'Google::Ads::AdWords::v201309::ProductAd',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'getResponse/rval/entries/ad[DynamicSearchAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[DynamicSearchAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'mutate/operations/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[DynamicSearchAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/businessName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[RichMediaAd]/adDuration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[ImageError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/sourceUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[DeprecatedAd]' => 'Google::Ads::AdWords::v201309::DeprecatedAd',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[ImageAd]/image' => 'Google::Ads::AdWords::v201309::Image',
               'mutateResponse/rval/partialFailureErrors[AdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/duration' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'queryResponse/rval/entries/ad[TemplateAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'getResponse/rval/entries/ad[ImageAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201309::QuotaCheckError::Reason',
               'getResponse/rval/entries/ad[MobileAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[DeprecatedAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[MobileAd]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[DeprecatedAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/ad[MobileAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/partialFailureErrors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileAd]/mobileCarriers' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]' => 'Google::Ads::AdWords::v201309::Audio',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ImageAd]/image/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201309::OrderBy',
               'mutateResponse/rval/value/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/isExemptable' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[MediaError]/reason' => 'Google::Ads::AdWords::v201309::MediaError::Reason',
               'mutateResponse/rval/partialFailureErrors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ImageAd]/image/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[MobileImageAd]/image/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201309::RequiredError::Reason',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201309::AdxError::Reason',
               'mutateResponse/rval/partialFailureErrors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[RichMediaAd]/impressionBeaconUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201309::ReadOnlyError::Reason',
               'getResponse/rval/entries/ad[RichMediaAd]/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201309::NullError::Reason',
               'mutateResponse/rval/partialFailureErrors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201309::IdError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[ImageAd]/image/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/dimensions' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PagingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/durationMillis' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mimeType' => 'Google::Ads::AdWords::v201309::Media::MimeType',
               'mutateResponse/rval/value/ad[DeprecatedAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[RichMediaAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[DynamicSearchAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[RichMediaAd]/snippet' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ForwardCompatibilityError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[ImageAd]/image/dimensions/value/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[MobileAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201309::String_StringMapEntry',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201309::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[RichMediaAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/type' => 'Google::Ads::AdWords::v201309::TemplateElementField::Type',
               'queryResponse/rval/entries/ad[TextAd]/headline' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'getResponse/rval/entries/ad[MobileImageAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201309::RateExceededError::Reason',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupAdCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/Media.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201309::ApiException',
               'queryResponse/rval/entries/ad[RichMediaAd]/dimensions/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[MediaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutate/operations/operand/ad[ImageAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/adUnionId[TempAdUnionId]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/adUnionId/AdUnionId.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[MobileImageAd]/image/urls/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'getResponse/rval/entries/ad[RichMediaAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[ThirdPartyRedirectAd]/adAttributes' => 'Google::Ads::AdWords::v201309::RichMediaAd::AdAttribute',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TextAd]/description2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[ImageAd]/image/referenceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201309::NotWhitelistedError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201309::RequestError::Reason',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]' => 'Google::Ads::AdWords::v201309::InternalApiError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad[ThirdPartyRedirectAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/fileSize' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/youTubeVideoIdString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[PolicyViolationError]/externalPolicyDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[PolicyViolationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'getResponse/rval/entries/ad/url' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/streamingUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/approvalStatus' => 'Google::Ads::AdWords::v201309::AdGroupAd::ApprovalStatus',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/type' => 'Google::Ads::AdWords::v201309::Media::MediaType',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201309::EntityCountLimitExceeded::Reason',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia/dimensions/key' => 'Google::Ads::AdWords::v201309::Media::Size',
               'mutateResponse/rval/value/ad' => 'Google::Ads::AdWords::v201309::Ad',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Audio]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/creationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'mutateResponse/rval/value/ad[ProductAd]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia' => 'Google::Ads::AdWords::v201309::Media',
               'mutateResponse/rval/value/ad[MobileImageAd]/image/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/ad[MobileAd]/markupLanguages' => 'Google::Ads::AdWords::v201309::MarkupLanguageType',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/isCookieTargeted' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/urls' => 'Google::Ads::AdWords::v201309::Media_Size_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201309::ClientTermsError::Reason',
               'mutate/operations/operand/ad[RichMediaAd]/devicePreference' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/ad[TemplateAd]/templateElements/fields/fieldMedia[Video]/dimensions' => 'Google::Ads::AdWords::v201309::Media_Size_DimensionsMapEntry',
               'mutate/operations/operand/ad/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileImageAd]/image/dimensions/value' => 'Google::Ads::AdWords::v201309::Dimensions',
               'queryResponse/rval/entries/ad[ThirdPartyRedirectAd]' => 'Google::Ads::AdWords::v201309::RichMediaAd',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201309::AdGroupAd',
               'mutateResponse/rval/partialFailureErrors[AdGroupAdCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/adUnionId' => 'Google::Ads::AdWords::v201309::AdUnionId',
               'getResponse/rval/entries/ad[ThirdPartyRedirectAd]/dimensions/height' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/ad[ImageAd]/image/dimensions/value/width' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/ad[DeprecatedAd]/displayUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/ad[TemplateAd]/templateElements/fields/fieldMedia[Image]/mediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/ad[MobileImageAd]' => 'Google::Ads::AdWords::v201309::MobileImageAd',
               'mutate/operations' => 'Google::Ads::AdWords::v201309::AdGroupAdOperation',
               'mutateResponse/rval/value/ad[TemplateAd]/Ad.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201309::TypeMaps::AdGroupAdService - typemap for AdGroupAdService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

